<?php
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );
/*
	Plugin Name: Hex Review Listing
	Plugin URI:  https://www.hexco.nl/hex-review-listing-1-0/
	Description: Laat via een shortcode jouw cijfer weergeven!
	Version:     1.0
	Author:      Hexco Webdesign
	Author URI:  http://www.hexco.nl/
	License:     GPL2
	License URI: https://www.gnu.org/licenses/gpl-2.0.html
	Text Domain: hex-review-listing
	Domain Path: /languages

	Hex Review Listing is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 2 of the License, or
	any later version.
	 
	Hex Review Listing is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
	 
	You should have received a copy of the GNU General Public License
	along with Hex Review Listing. If not, see https://www.gnu.org/licenses/gpl-2.0.html.
*/

// START Talen
// Localization
	if ( !function_exists( 'hex_review_localization' ) ) {
		add_action('init', 'hex_review_localization');
		function hex_review_localization() {
			$path = dirname(plugin_basename( __FILE__ )) . '/languages/';
			$loaded = load_plugin_textdomain( 'hex-review-listing', false, $path);
			if ($_GET['page'] == basename(__FILE__) && !$loaded) {          
				echo '<div class="error">Sample Localization: ' . __('Probleem met laden van vertaling: ' . $path, 'hex-review-listing') . '</div>';
				return;
			} 
		} 
	}
// END Talen

// START CSS
	if ( !function_exists( 'hex_review_listing_init' ) ) {
		function hex_review_listing_init() {
			$hex_review_style = get_option( 'hex_review_style' );
			if(!empty($hex_review_style)){
				wp_register_style('hex_review', plugins_url('assets/css/'.$hex_review_style.'.css',__FILE__ ));
			}else{
				wp_register_style('hex_review', plugins_url('assets/css/basic.css',__FILE__ ));
			}
			wp_enqueue_style('hex_review');
		}

		add_action( 'wp_enqueue_scripts','hex_review_listing_init');
	}
// END CSS

// START Shortcode
	if ( !function_exists( 'hex_review' ) ) {
		function hex_review(){
			$hex_review_style = get_option( 'hex_review_style' );
			$reviewpage = get_option( 'hex_review_url' );
			if($hex_review_style == 'ak'){
				$logo = plugins_url('assets/ak_logo.png',__FILE__ );
				$website = 'Advieskeuze.nl';
			}elseif($hex_review_style == 'booking'){
				$logo = plugins_url('assets/booking_logo.png',__FILE__ );
				$website = 'Booking.com';
			}else{
				$website = 'Onze';
				$logo = plugins_url('assets/blanco.png',__FILE__ );
			}
			
			$review = '
				<div class="score small" itemprop="aggregateRating" itemscope="" itemtype="http://schema.org/AggregateRating">
					<div class="scoreHeader"><h2 itemprop="name">'.sprintf( esc_html__( '%s Score', 'hex-review-listing' ), $website).'</h2></div>
					<div class="scoreLarge" itemprop="ratingValue"><span>'.get_option( 'hex_review_cijfer' ).'</span></div>
					<meta itemprop="bestRating" content="10" />
					<meta itemprop="worstRating" content="1" />
					<meta itemprop="image" content="'.$logo.'" />
					<div class="scoreBezoeken">
					<a href="'.$reviewpage.'" target="_blank">'.sprintf(esc_html( _n( 'Bekijk <span itemprop="reviewCount">%d</span> beoordeling', 'Bekijk alle <span itemprop="reviewCount">%d</span> beoordelingen', get_option( 'hex_review_recensie' ), 'hex-review-listing'  ) )).'</a>
					</div>
				</div>
			';

			return $review;
		}
		
		add_shortcode('hex_review', 'hex_review');
	}
// END Shortcode


if ( is_admin() ) {
	require plugin_dir_path(__FILE__).'hex-review-widget.php';
	
	// START Admin menu
		if ( !function_exists( 'hex_review_add_pages' ) ) {
			function hex_review_add_pages() {
				add_menu_page('Review Cijfer', 'Review Cijfer', 'manage_options', 'hex-review-listing-menu', 'hex_review_listing' );
			}
			add_action('admin_menu', 'hex_review_add_pages');
		}
	// END Admin menu


	// START Admin pagina
		if ( !function_exists( 'hex_review_listing' ) ) {
			function hex_review_listing() {

				if (!current_user_can('manage_options'))
				{
				  wp_die( __('You do not have sufficient permissions to access this page.') );
				}

				$hidden_field_name = 'hex_review_submit_hidden';
				$cijfer_name = 'hex_review_cijfer';
				$recensie_name = 'hex_review_recensie';
				$style_name = 'hex_review_style';
				$reviewurl_name = 'hex_review_url';
				
				$recensie = 'hex_review_recensie';
				$cijfer = 'hex_review_cijfer';
				$style = 'hex_review_style';
				$reviewurl = 'hex_review_url';
				
				$cijfer_val = get_option( $cijfer_name );
				$recensie_val = get_option( $recensie_name );
				$style_val = get_option( $style_name );
				$reviewurl_val = get_option( $reviewurl_name );
				echo '
					<div class="wrap">
						<h2>'.esc_html__( 'Hex Review Cijfer', 'hex-review-listing' ).'</h2>';
				if( isset($_POST[ $hidden_field_name ]) && $_POST[ $hidden_field_name ] == 'Y' ) {
					$cijfer_val = sanitize_text_field($_POST[ $cijfer ]);
					$recensie_val = sanitize_text_field($_POST[ $recensie ]);
					$style_val = sanitize_text_field($_POST[ $style ]);
					$reviewurl_val = sanitize_text_field($_POST[ $reviewurl ]);
					
					update_option( $cijfer_name, $cijfer_val );
					update_option( $recensie_name, $recensie_val );
					update_option( $style_name, $style_val );
					update_option( $reviewurl_name, $reviewurl_val );
					
					echo '<div class="updated"><p><strong>'.esc_html__( 'Waardes opgeslagen', 'hex-review-listing' ).'</strong></p></div>';
				}

				echo '
						<form name="form1" method="post" action="">
							<input type="hidden" name="'.$hidden_field_name.'" value="Y">
							<h2>'.esc_html__( 'Cijfer', 'hex-review-listing' ).'</h2>
							<p>'.esc_html__( 'Totaal cijfer:', 'hex-review-listing' ).' 
								<input type="text" name="'.$cijfer.'" value="'.$cijfer_val.'" size="20">
							</p>

							<p>'.esc_html__( 'Aantal Recensies:', 'hex-review-listing' ).'
								<input type="text" name="'.$recensie.'" value="'.$recensie_val.'" size="20">
							</p>

							<p>'.esc_html__( 'Review link:', 'hex-review-listing' ).'
								<input type="text" name="'.$reviewurl.'" value="'.$reviewurl_val.'" size="100">
							</p><hr />

							<h2>'.esc_html__( 'Opmaak', 'hex-review-listing' ).'</h2>
							<p>'.esc_html__( 'CSS Style:', 'hex-review-listing' ).'
								<select name="'.$style.'">
									<option value="basic" '.(($style_val=='basic')?'selected="selected"':"").'>Standaard</option>
									<option value="ak" '.(($style_val=='ak')?'selected="selected"':"").'>AdviesKeuze</option>
									<option value="booking" '.(($style_val=='booking')?'selected="selected"':"").'>Booking.com</option>
								</select>
							</p><hr />

							<p class="submit">
								<input type="submit" name="Submit" class="button-primary" value="'.esc_html__( 'Wijzigingen Opslaan', 'hex-review-listing' ).'" />
							</p>
						</form>
					</div>';

			}
		}
	// END Admin pagina
}